Unbound

Trait Unbound 

pub trait Unbound {
    type Bound<'a>
       where Self: 'a;

    // Required method
    unsafe fn transmute_lifetime<'a, 'b>(
        value: Self::Bound<'a>,
    ) -> Self::Bound<'b>
       where Self: 'a + 'b;
}

Required Associated Types

type Bound<'a> where Self: 'a

Required Methods

unsafe fn transmute_lifetime<'a, 'b>(value: Self::Bound<'a>) -> Self::Bound<'b>
where Self: 'a + 'b,

Transmutes the lifetime parameter of the given bound value.

Safety

The caller must ensure the value lives for 'a and 'b.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: UnboundIterator> Unbound for T

Source

type Bound<'a> = <T as UnboundIterator>::Bound<'a> where Self: 'a

Source

impl<T> Unbound for UnboundOwned<T>

Source

type Bound<'a> = T where Self: 'a

Source

impl<T> Unbound for UnboundRef<T>

Source

type Bound<'a> = &'a T where Self: 'a