pub trait Unbound {
type Bound<'a>
where Self: 'a;
// Required method
unsafe fn transmute_lifetime<'a, 'b>(
value: Self::Bound<'a>,
) -> Self::Bound<'b>
where Self: 'a + 'b;
}Required Associated Types
Required Methods
Sourceunsafe fn transmute_lifetime<'a, 'b>(value: Self::Bound<'a>) -> Self::Bound<'b>where
Self: 'a + 'b,
unsafe fn transmute_lifetime<'a, 'b>(value: Self::Bound<'a>) -> Self::Bound<'b>where
Self: 'a + 'b,
Transmutes the lifetime parameter of the given bound value.
Safety
The caller must ensure the value lives for 'a and 'b.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".